%"Copyright 2015 Isaac Jose Manjarres"

%This program is free software: you can redistribute it and/or modify
%it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or
%(at your option) any later version.

%The Mako Eye Tracking Toolbox is distributed in the hope that it will be useful,
%but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%GNU General Public License for more details.

%You should have received a copy of the GNU General Public License
%along with this program.  If not, see <http://www.gnu.org/licenses/>.

%Name: createGazeCalibrationLog
%Parameters: subjectNumber, stimuliPath
%The purpose of this function is to create a calibration log for a subject. 
%This log is used to store the LX, LY, RX, and RY deviations as observed by the
%eye tracker during the calibration phase. The calibration log is stored in the
%results subdirectory of the Infrastructure directory under the title:
%calibration_timestamp, where timestamp is the timestamp of when the experiment
%began. Note: the file descriptor opened by this function is not closed when 
%it returns, as it's necessary that it stays open for writing the calibration 
%information later.
function gazeCalibLogFD = createGazeCalibrationLog(stimuliPath)
  %Create path to the results subdirectory
  resultsPath = strrep(stimuliPath, 'Stimuli', 'Results');
  if(exist(resultsPath, 'dir') ~=7)
    fprintf(['ERROR: There is no "Results" subdirectory within the'...
            ' Infrastructure directory. Since it was not found, the program'...
            ' will now abort.\n']);
    setGlobalAbortValue(abortProgram);
    gazeDataFD = [];
    return
  end
  %Create path to file
  systemTime = clock;
  month = int2str(systemTime(2));
  day = int2str(systemTime(3));
  year = int2str(systemTime(1));
  hour = int2str(systemTime(4));
  minutes = int2str(systemTime(5));
  seconds = int2str(systemTime(6));
  year = year(3:length(year));
  if(length(month) == 1)
    month = strcat('0', month);
  end
  if(length(day) == 1)
    day = strcat('0', day);
  end
  if(length(hour) == 1)
    hour = strcat('0', hour);
  end
  if(length(minutes) == 1)
    minutes = strcat('0', minutes);
  end
  if(length(seconds) == 1)
    seconds = strcat('0', seconds);
  end
  timeStamp = sprintf('%s%s%s_%s%s%s', month, day, year, hour, minutes,...
                      seconds);
  fileName = sprintf('%s_%s%s', 'calibration', timeStamp, '.csv');
  filePath = sprintf('%s\\%s', resultsPath, fileName);
  gazeCalibLogFD = fopen(filePath, 'w+');
  %Print header into the calibration log
  fprintf(gazeCalibLogFD, ['TimeStamp,Subject ID,Deviation LX, Deviation LY,'...
                           'Deviation RX,Deviation RY\r\n']);
  fprintf(gazeCalibLogFD, '%s,', timeStamp);
  return

