%"Copyright 2015 Isaac Jose Manjarres"

%This program is free software: you can redistribute it and/or modify
%it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or
%(at your option) any later version.

%The Mako Eye Tracking Toolbox is distributed in the hope that it will be useful,
%but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%GNU General Public License for more details.

%You should have received a copy of the GNU General Public License
%along with this program.  If not, see <http://www.gnu.org/licenses/>.

%Name: createGazeDataLog
%Parameters: stimuliPath, timeStamp
%This function is a subfunction for the top function that will be running the 
%experiment. The purpose of this function is to create a file descriptor for a 
%CSV file that will be used to store the eye tracking data collected by the 
%iView X eye tracker. It also creates the file such that it will have a header 
%as seen in the code. 
function gazeDataFD = createGazeDataLog(stimuliPath, timeStamp)
  %Given the stimuli path, we can remove the word stimuli and make it into 
  %results, which is where the data log will be stored in our infrastructure
  %folder 
  timeStamp = datestr(clock, 'mmddyy_HHMMSS');
  format long;
  resultsPath = strrep(stimuliPath, 'Stimuli', 'Results');
  %If directory does not exist, terminate program.
  if(exist(resultsPath, 'dir') ~=7)
    fprintf(['ERROR: There is no "Results" subdirectory within the'...
            ' Infrastructure directory. Since it was not found, the program'...
            ' will now abort.\n']);
    gazeDataFD = [];
    return
  end
  %Create path to file
  
  fileName = sprintf('%s%s', timeStamp, '.csv');
  filePath = sprintf('%s\\%s', resultsPath, fileName);
  gazeDataFD = fopen(filePath, 'w');
  %create header for file
  fprintf(gazeDataFD, ['Stimuli Name,Stimuli ID,Timestamp,LeftEyeGazeX,'...
                      'Left Eye Gaze,Left Eye Diameter\r\n']);
  return