%"Copyright 2015 Isaac Jose Manjarres"

%This program is free software: you can redistribute it and/or modify
%it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or
%(at your option) any later version.

%The Mako Eye Tracking Toolbox is distributed in the hope that it will be useful,
%but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%GNU General Public License for more details.

%You should have received a copy of the GNU General Public License
%along with this program.  If not, see <http://www.gnu.org/licenses/>.

%Author: Isaac Jose Manjarres
%Name: plotDataOnImage
%Parameters: imageFile, rawData
%The purpose of this function is to extract gaze data from a CSV file that 
%contains x and y gaze coordinates, that were collected when looking at an image
%and then superimposing them on the image. 
function plotDataOnImage(imageFile, rawData)
  %We begin by parsing the data and extracting the x and y data points 
  %Open a file descriptor so that we can read from the data 
  xCoordinates = [];
  yCoordinates = [];
  xCoordinateColumn = 2;
  yCoordinateColumn = 3;
  rawDataFD = fopen(rawData, 'r');
  %We begin by bypassing the first line
  currentLine = fgets(rawDataFD);
  %move to second line
  currentLine = fgets(rawDataFD);
  %extract data points by picking out x and y data. Based off of the way that 
  %the gaze data log is structured, we can determine that for every entry that
  %is recovered from fgets, the second and third entry in the matrix obtained
  %from strsplit are the x and y coordinates of the data points.
  while(ischar(currentLine))
    data = strsplit(currentLine, ',');
    xCoordinates(end + 1) = str2double(data(xCoordinateColumn));
    yCoordinates(end + 1) = str2double(data(yCoordinateColumn));
    currentLine = fgets(rawDataFD);
  end
  %We no longer need to read anything from the raw data, so we can close the 
  %file descriptor associated with it
  fclose(rawDataFD);
  %Now we load the image natrix via a call to imread.
  imageMatrix = imread(imageFile);
  %show image
  imshow(imageMatrix);
  hold on;
  scatter(xCoordinates, yCoordinates, 'y');
  return

